#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include "ostdb.h"
#include "loadfile.h"
#include "loadutils.h"
#include "cdbs_sql_gen.h"

/*
*****************************************************************************
*
* Function: get_modes
*
* Purpose: Queries the database table cdbs_mode to determine which modes are
*          used for a particular reference file type. It allocates a structure
*          to hold the name and value of the keyword and inserts its address
*          into the mode_key array that was passed in.
*
* Returns: The number of mode keywords for the reference file type
*
*****************************************************************************
*/
int get_modes(char *instrument, 
              char *reference_file_type, 
	      KeyList *mode_key[])
{

  char table[31];
  sprintf(table, "%s_row", instrument);
  LowCase(table);
  
  /*
   * Get the column names in the instrument row table
   */
  ostdb_query_setup(STDB_CONN_1, "get_modes", 1, STDB_SQL, "CDBS_SERVER",
		    "CDBS_DEB", NULL);

  char modes[31];
  stdb_string_param(STDB_CONN_1, "instrument", instrument);
  stdb_string_param(STDB_CONN_1, "reference_file_type", reference_file_type);
  stdb_bind_string(STDB_CONN_1, "modes", modes, 0);

  stdb_query(STDB_CONN_1,"SELECT modes FROM cdbs_mode");
  stdb_query(STDB_CONN_1, "WHERE upper(instrument) = @instrument");
  stdb_query(STDB_CONN_1, "and upper(reference_file_type) = @reference_file_type");

  int i = 0;
  while(ostdb_get_exec(STDB_CONN_1) == STDB_CONTINUE){
    mode_key[i] = (KeyList *)malloc(sizeof(KeyList));
    strcpy(mode_key[i]->db_name, modes);
    mode_key[i]->quoted = QuotedField("CDBS_SERVER", "CDBS_DB", table, modes);
    strcpy(mode_key[i]->colname, UpCase(modes));
    i++;
  }

  stdb_close_query(STDB_CONN_1);

  if (ostdb_get_status(STDB_CONN_1) != OSTDB_NORMAL){
    return ERROR;
  }

  return i;
}

